@@ -2,7 +2,7 @@ package SVG::XML;
 use strict;
 use warnings;
 
-our $VERSION = '2.72';
+our $VERSION = '2.73';
 
 =pod
 
@@ -85,14 +85,18 @@ sub cssstyle {
 # Per suggestion from Adam Schneider
 sub xmlattrib {
     my %attrs = @_;
+    return '' unless ( scalar( keys %attrs ) );
     return (
-        join( ' ', map { qq($_=") . $attrs{$_} . q(") } sort keys(%attrs) ) );
+        ' '
+            . join( ' ',
+            map { qq($_=") . $attrs{$_} . q(") } sort keys(%attrs) )
+    );
 }
 
 sub xmltag {
     my ( $name, $ns, %attrs ) = @_;
     $ns = $ns ? "$ns:" : '';
-    my $at = ' ' . xmlattrib(%attrs) || '';
+    my $at = xmlattrib(%attrs) || '';
     return qq(<$ns$name$at />);
 }
 
@@ -104,7 +108,7 @@ sub xmltag_ln {
 sub xmltagopen {
     my ( $name, $ns, %attrs ) = @_;
     $ns = $ns ? "$ns:" : '';
-    my $at = ' ' . xmlattrib(%attrs) || '';
+    my $at = xmlattrib(%attrs) || '';
     return qq(<$ns$name$at>);
 }
 
